@@ -1,5 +1,6 @@
 /*
  * Copyright 2013 Canonical Ltd.
+ * Copyright 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -16,6 +17,7 @@
  * Authors:
  *   Ted Gould <ted@canonical.com>
  *   Charles Kerr <charles.kerr@canonical.com>
+ *   Robert Tari <robert@tari.in>
  */
 
 #ifndef AYATANA_INDICATOR_NOTIFICATIONS_DBUS_SHARED_H
@@ -25,12 +27,12 @@
 #define BUS_SCREEN_PATH      "/com/canonical/Unity/Screen"
 #define BUS_SCREEN_INTERFACE "com.canonical.Unity.Screen"
 
-#define BUS_POWERD_NAME      "com.canonical.powerd"
-#define BUS_POWERD_PATH      "/com/canonical/powerd"
-#define BUS_POWERD_INTERFACE "com.canonical.powerd"
+#define BUS_POWERD_NAME      "com.lomiri.Repowerd"
+#define BUS_POWERD_PATH      "/com/lomiri/Repowerd"
+#define BUS_POWERD_INTERFACE "com.lomiri.Repowerd"
 
-#define BUS_HAPTIC_NAME      "com.canonical.usensord"
-#define BUS_HAPTIC_PATH      "/com/canonical/usensord/haptic"
-#define BUS_HAPTIC_INTERFACE "com.canonical.usensord.haptic"
+#define BUS_HAPTIC_NAME      "com.lomiri.hfd"
+#define BUS_HAPTIC_PATH      "/com/lomiri/hfd"
+#define BUS_HAPTIC_INTERFACE "com.lomiri.hfd.Vibrator"
 
 #endif /* INDICATOR_NOTIFICATIONS_DBUS_SHARED_H */
